@@ -270,7 +270,7 @@ void bowl_select_next_block( Bowl *bowl )
 	if (bowl_check_piece_position(bowl,
 			bowl->block.x, bowl->block.y,
 			bowl->block.rot_id) != POSVALID)
-		bowl_finish_game(bowl);
+		bowl_finish_game(bowl,0);
 }
 
 /*
@@ -527,20 +527,32 @@ void bowl_final_animation( Bowl *bowl )
 
 /*
 ====================================================================
-Finish game and set game over.
+Finish game and set game over. If winner is 1 show win message.
 ====================================================================
 */
-void bowl_finish_game( Bowl *bowl )
+void bowl_finish_game( Bowl *bowl, int winner )
 {
+    char *msg = (winner)?_("Winner!"):_("Game Over");
+    int mx = bowl->sx + bowl->sw / 2, my = bowl->sy + bowl->sh / 2;
+
     bowl->game_over = 1;
     bowl->hide_block = 1;
     bowl_final_animation( bowl );
     bowl->use_figures = 0;
+
+    /* add stats for multiplayer game and move message down */
+    if (config.gametype >= GAME_VS_HUMAN && config.gametype <= GAME_VS_CPU_CPU) {
+	    bowl->stats_x = bowl->sx + BOWL_BLOCK_SIZE;
+	    bowl->stats_y = bowl->sy + BOWL_BLOCK_SIZE;
+	    bowl_draw_stats(bowl);
+	    my = bowl->sy + bowl->sh - 3*BOWL_BLOCK_SIZE;
+    }
+
+    /* clear bowl and write message */
     bowl->font->align = ALIGN_X_CENTER | ALIGN_Y_CENTER;
-    write_text( bowl->font,  bkgnd, bowl->sx + bowl->sw / 2, bowl->sy + bowl->sh / 2, _("Game Over"), OPAQUE );
-    write_text( bowl->font, sdl.screen, bowl->sx + bowl->sw / 2, bowl->sy + bowl->sh / 2, _("Game Over"), OPAQUE );
-    bowl_reset_contents( bowl );
-    bowl_draw_contents( bowl );
+    write_text(bowl->font, bkgnd, mx, my, msg, OPAQUE);
+    bowl_reset_contents(bowl);
+    bowl_draw_contents(bowl);
 #ifdef SOUND
     if ( !bowl->mute ) sound_play( bowl->wav_explosion );
 #endif    
@@ -567,28 +579,24 @@ void bowl_add_score(Bowl *bowl, int lc)
 /** Add lines to counter and check if new level has been entered. */
 void bowl_add_lines( Bowl *bowl, int cleared)
 {
-	int levelup = 0;
+	bowl->levelup = 0;
 
 	/* check level up date, first level might need more than 10
 	 * if higher starting level was chosen */
 	if (bowl->lines < bowl->firstlevelup_lines) {
 		if (bowl->lines + cleared >= bowl->firstlevelup_lines)
-			levelup = 1;
+			bowl->levelup = 1;
 	} else {
 		int l = bowl->lines - bowl->firstlevelup_lines;
 		if (l / 10 != (l + cleared) / 10)
-			levelup = 1;
+			bowl->levelup = 1;
 	}
 
 	bowl->lines += cleared; /* increase lines count */
 
-	if (levelup) {
-		bowl->level = config.starting_level + 1 +
-				(bowl->lines - bowl->firstlevelup_lines) / 10;
+	if (bowl->levelup) {
+		bowl->level++;
 		bowl_set_vert_block_vel( bowl );
-		/* in game figures reset bowl contents */
-		if ( config.gametype == 2 )
-			bowl_reset_contents( bowl );
 #ifdef SOUND
 		if (!bowl->mute)
 			sound_play( bowl->wav_nextlevel );
@@ -608,6 +616,15 @@ void bowl_collapse(Bowl *bowl)
 			bowl_set_tile(bowl, i, 0, -1);
 		}
 	bowl->cleared_line_count = 0;
+
+	/* in game figures reset bowl contents */
+	if (bowl->levelup && config.gametype == 2)
+		bowl_reset_contents(bowl);
+
+	/* collapse gets called after lines were removed with ARE.
+	 * add_lines in insert_block checked if this caused a level up.
+	 * so we always have to reset the flag here. */
+	bowl->levelup = 0;
 }
 
 /*
@@ -714,7 +731,8 @@ void bowl_insert_block( Bowl *bowl )
   bowl->are = 1000 * bowl->are / 60;
 
   /* add lines and check level update */
-  bowl_add_lines(bowl, bowl->cleared_line_count);
+  if (bowl->cleared_line_count > 0)
+    bowl_add_lines(bowl, bowl->cleared_line_count);
 
   /* add score */
   bowl_add_score(bowl, bowl->cleared_line_count);
@@ -743,7 +761,7 @@ void bowl_insert_block( Bowl *bowl )
 	      for (j = 0; j < send_count; j++)
 		      if (!bowl_add_line( bowls[i],
 				      	      (config.rand_holes)?config.holes:-1, newline)) {
-			      bowl_finish_game( bowls[i] );
+			      bowl_finish_game( bowls[i], 0 );
 			      break;
 		      }
 	      bowls[i]->draw_contents = 1;
@@ -1471,7 +1489,7 @@ void bowl_update( Bowl *bowl, int ms, BowlControls *bc, int game_over )
 		    bowl->ldelay_cur = 0; /* reset lock delay if any */
 		    bowl_use_hold(bowl);
 		    if (bowl->game_over)
-			bowl_finish_game(bowl);
+			bowl_finish_game(bowl,0);
 	    }
 
         /* update horizontal bowl position */
@@ -1857,6 +1875,8 @@ void write_stat_line(Bowl *bowl, const char *name, int val, int x, int *y)
 		snprintf(str, 32, "%s -", name );
 	else
 		snprintf(str, 32, "%s %d", name, val );
+	if (bowl->game_over)
+		write_text(bowl->font, bkgnd, x, *y, str, OPAQUE );
 	write_text(bowl->font, sdl.screen, x, *y, str, OPAQUE );
 	*y += bowl->font->height + 2;
 }
