@@ -74,8 +74,8 @@ void config_reset()
     config.send_all = 0;
     config.send_tetris = 1;
     /* cpu */
-    config.cpu_aggr = 1;
-    config.cpu_delay = 700;
+    config.cpu_style = CS_NORMAL;
+    config.cpu_delay = 500;
     config.cpu_rot_delay = 100;
     config.cpu_sfactor = 100;
     /* controls */
@@ -190,7 +190,7 @@ void config_load( )
     parser_get_int( pd, "gp_pause", &config.gp_pause );
     parser_get_int( pd, "gp_hold", &config.gp_hold );
 
-    parser_get_int( pd, "cpu_aggr", &config.cpu_aggr );
+    parser_get_int( pd, "cpu_style", &config.cpu_style );
     parser_get_int( pd, "cpu_delay", &config.cpu_delay );
     parser_get_int( pd, "cpu_rot_delay", &config.cpu_rot_delay );
     parser_get_int( pd, "cpu_sfactor", &config.cpu_sfactor );
@@ -263,7 +263,7 @@ void config_save( )
         fprintf( file, "gp_pause=%d\n", config.gp_pause );
         fprintf( file, "gp_hold=%d\n", config.gp_hold );
 
-        fprintf( file, "cpu_aggr=%i\n", config.cpu_aggr );
+        fprintf( file, "cpu_style=%i\n", config.cpu_style );
         fprintf( file, "cpu_delay=%i\n", config.cpu_delay );
         fprintf( file, "cpu_rot_delay=%i\n", config.cpu_rot_delay );
         fprintf( file, "cpu_sfactor=%d\n", config.cpu_sfactor );
