@@ -37,10 +37,11 @@ extern int display_w, display_h, video_forced_w, video_forced_h;
 
 int main(int argc, char *argv[])
 {
-	int c;
+    int c;
     int result = ACTION_NONE;
     int leave = 0;
     const SDL_VideoInfo* info;
+    int test_alg = 0;
 
     /* i18n */
 #ifdef ENABLE_NLS
@@ -50,7 +51,7 @@ int main(int argc, char *argv[])
 #endif
     
     /* ltris info */
-    printf( "LTris %s\nCopyright 2002-2023 Michael Speck\nPublished under GNU GPL\n---\n", VERSION );
+    printf( "LTris %s\nCopyright 2002-2024 Michael Speck\nPublished under GNU GPL\n---\n", VERSION );
     printf( "Looking up data in: %s\n", SRC_DIR );
 #ifndef SOUND
     printf( "Compiled without sound and music\n" );
@@ -80,7 +81,7 @@ int main(int argc, char *argv[])
     strcpy(gametype_names[8],_("Training"));
     config_load();
 
-    while ( ( c = getopt( argc, argv, "fwr:" ) ) != -1 )
+    while ( ( c = getopt( argc, argv, "Ttfwr:" ) ) != -1 )
       {
         switch (c)
   	{
@@ -91,6 +92,12 @@ int main(int argc, char *argv[])
   		printf("Trying to force resolution %dx%d\n",
   				video_forced_w, video_forced_h);
   		break;
+  	case 't':
+  		test_alg = 1; /* test CPU algorithm in console, single run */
+  		break;
+  	case 'T':
+  		test_alg = 2; /* test CPU algorithm in console, test range */
+  		break;
   	}
       }
 
@@ -137,14 +144,20 @@ int main(int argc, char *argv[])
     /* run game */
     manager_fade( FADE_IN );
     while( !leave && !term_game ) {
+
+	    /* test algorithm on console? */
+	    if (test_alg) {
+		    tetris_init();
+		    tetris_test_cpu_algorithm(test_alg);
+		    tetris_clear();
+		    break;
+	    }
+
         result = manager_run();
         switch( result ) {
-            case ACTION_QUIT: leave = 1; break;
-            case ACTION_MAKE_STAT:
-                manager_fade( FADE_OUT );
-                tetris_make_stat();
-                manager_fade( FADE_IN );
-                break;
+            case ACTION_QUIT:
+        	    leave = 1;
+        	    break;
             case ACTION_PLAY:
                 manager_fade( FADE_OUT );
                 if ( tetris_init() ) {
@@ -159,8 +172,8 @@ int main(int argc, char *argv[])
     manager_fade( FADE_OUT );
     /* delete stuff */
     tetris_delete();
-	manager_delete();
-	chart_save();
+    manager_delete();
+    chart_save();
     chart_delete();
     hint_delete_res();
     
